---
name: Bug report
about: Create an Awpy bug report
title: ""
labels: ""
assignees: ""
---

**Describe the bug**
A description of what the bug is.

**Include Information to Reproduce**
Please include any code, as well as information on your OS or computing environment.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Additional context**
Add any other context about the problem here.
